==> zio-aws-acmpca_2.13-5.17.104.8-sources.jar: zio/aws/acmpca/model/GetCertificateResponse.scala <==
package zio.aws.acmpca.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.acmpca.model.primitives.{CertificateChain, CertificateBody}
import scala.jdk.CollectionConverters._
final case class GetCertificateResponse(
    certificate: Option[CertificateBody] = None,
    certificateChain: Option[CertificateChain] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.acmpca.model.GetCertificateResponse = {
    import GetCertificateResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.acmpca.model.GetCertificateResponse
      .builder()
      .optionallyWith(
        certificate.map(value =>
          CertificateBody.unwrap(value): java.lang.String
        )
      )(_.certificate)
      .optionallyWith(
        certificateChain.map(value =>
          CertificateChain.unwrap(value): java.lang.String
        )
      )(_.certificateChain)
      .build()
  }
  def asReadOnly: zio.aws.acmpca.model.GetCertificateResponse.ReadOnly =
    zio.aws.acmpca.model.GetCertificateResponse.wrap(buildAwsValue())
}
object GetCertificateResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.acmpca.model.GetCertificateResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.acmpca.model.GetCertificateResponse =
      zio.aws.acmpca.model.GetCertificateResponse(
        certificate.map(value => value),
        certificateChain.map(value => value)
      )
    def certificate: Option[CertificateBody]
    def certificateChain: Option[CertificateChain]
    def getCertificate: ZIO[Any, AwsError, CertificateBody] =
      AwsError.unwrapOptionField("certificate", certificate)
    def getCertificateChain: ZIO[Any, AwsError, CertificateChain] =
      AwsError.unwrapOptionField("certificateChain", certificateChain)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.acmpca.model.GetCertificateResponse
  ) extends zio.aws.acmpca.model.GetCertificateResponse.ReadOnly {
    override val certificate: Option[CertificateBody] = scala
      .Option(impl.certificate())
      .map(value => zio.aws.acmpca.model.primitives.CertificateBody(value))
    override val certificateChain: Option[CertificateChain] = scala
      .Option(impl.certificateChain())
      .map(value => zio.aws.acmpca.model.primitives.CertificateChain(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.acmpca.model.GetCertificateResponse
  ): zio.aws.acmpca.model.GetCertificateResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-acmpca_2.13-5.17.208.1-sources.jar: zio/aws/acmpca/model/GetCertificateResponse.scala <==
package zio.aws.acmpca.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.acmpca.model.primitives.{CertificateChain, CertificateBody}
import scala.jdk.CollectionConverters._
final case class GetCertificateResponse(
    certificate: Optional[CertificateBody] = Optional.Absent,
    certificateChain: Optional[CertificateChain] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.acmpca.model.GetCertificateResponse = {
    import GetCertificateResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.acmpca.model.GetCertificateResponse
      .builder()
      .optionallyWith(
        certificate.map(value =>
          CertificateBody.unwrap(value): java.lang.String
        )
      )(_.certificate)
      .optionallyWith(
        certificateChain.map(value =>
          CertificateChain.unwrap(value): java.lang.String
        )
      )(_.certificateChain)
      .build()
  }
  def asReadOnly: zio.aws.acmpca.model.GetCertificateResponse.ReadOnly =
    zio.aws.acmpca.model.GetCertificateResponse.wrap(buildAwsValue())
}
object GetCertificateResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.acmpca.model.GetCertificateResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.acmpca.model.GetCertificateResponse =
      zio.aws.acmpca.model.GetCertificateResponse(
        certificate.map(value => value),
        certificateChain.map(value => value)
      )
    def certificate: Optional[CertificateBody]
    def certificateChain: Optional[CertificateChain]
    def getCertificate: ZIO[Any, AwsError, CertificateBody] =
      AwsError.unwrapOptionField("certificate", certificate)
    def getCertificateChain: ZIO[Any, AwsError, CertificateChain] =
      AwsError.unwrapOptionField("certificateChain", certificateChain)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.acmpca.model.GetCertificateResponse
  ) extends zio.aws.acmpca.model.GetCertificateResponse.ReadOnly {
    override val certificate: Optional[CertificateBody] = zio.aws.core.internal
      .optionalFromNullable(impl.certificate())
      .map(value => zio.aws.acmpca.model.primitives.CertificateBody(value))
    override val certificateChain: Optional[CertificateChain] =
      zio.aws.core.internal
        .optionalFromNullable(impl.certificateChain())
        .map(value => zio.aws.acmpca.model.primitives.CertificateChain(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.acmpca.model.GetCertificateResponse
  ): zio.aws.acmpca.model.GetCertificateResponse.ReadOnly = new Wrapper(impl)
}
